Pair<A, B> class
a class with 2 values
- Available extensions
- Annotations
-
- @immutable
Constructors
- Pair(A $1, B $2)
-
default constructor
const
Properties
- $1 → A
-
first (left) value
final
- $2 → B
-
second (right) value
final
-
flipped
→ Pair<
B, A> -
gets a copy of this pair with values flipped
no setter
- hashCode → int
-
The hash code for this object.
no setteroverride
- index → int
-
Available on Pair<
get the $1 that represents the index of the IterableExtraExtensions.enumerate getterint, T> , provided by the PairExtraExtensions extensionno setter - left → A
-
convenience getter for $1
no setter
- right → B
-
convenience getter for $2
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → T
-
Available on Pair<
get the $2 that represents the value of the IterableExtraExtensions.enumerate getterint, T> , provided by the PairExtraExtensions extensionno setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override